=== modified file 'drizzled/create_field.h'
--- drizzled/create_field.h	2010-12-20 19:24:24 +0000
+++ drizzled/create_field.h	2011-02-04 18:26:39 +0000
@@ -24,7 +24,6 @@
 
 namespace drizzled
 {
-
 class Item;
 typedef struct st_typelib TYPELIB;
 

=== modified file 'drizzled/join.cc'
--- drizzled/join.cc	2011-01-26 23:20:53 +0000
+++ drizzled/join.cc	2011-02-04 19:50:47 +0000
@@ -67,7 +67,6 @@
 
 namespace drizzled
 {
-
 extern plugin::StorageEngine *heap_engine;
 
 /** Declarations of static functions used in this source file. */
@@ -4506,7 +4505,7 @@
       /* Ignore sj-nests: */
       if (!embedding->on_expr)
         continue;
-      nested_join_st *nested_join= embedding->getNestedJoin();
+      NestedJoin *nested_join= embedding->getNestedJoin();
       if (!nested_join->counter_)
       {
         /*
@@ -5246,7 +5245,7 @@
 static COND *simplify_joins(Join *join, List<TableList> *join_list, COND *conds, bool top)
 {
   TableList *table;
-  nested_join_st *nested_join;
+  NestedJoin *nested_join;
   TableList *prev_table= 0;
   List_iterator<TableList> li(*join_list);
 
@@ -5584,7 +5583,7 @@
       s->embedding_map.reset();
       do
       {
-        nested_join_st *nested_join= embedding->getNestedJoin();
+        NestedJoin *nested_join= embedding->getNestedJoin();
         s->embedding_map|= nested_join->nj_map;
         s->dependent|= embedding->getDepTables();
         embedding= embedding->getEmbedding();
@@ -5668,7 +5667,7 @@
     s= p_pos->getJoinTable();
     s->type= AM_SYSTEM;
     join->const_table_map|=s->table->map;
-    if ((tmp= join_read_const_table(s, p_pos)))
+    if ((tmp= s->joinReadConstTable(p_pos)))
     {
       if (tmp > 0)
         return 1;			// Fatal error
@@ -5742,7 +5741,7 @@
           join->const_table_map|=table->map;
           set_position(join, const_count++, s, (optimizer::KeyUse*) 0);
           partial_pos= join->getSpecificPosInPartialPlan(const_count - 1);
-          if ((tmp= join_read_const_table(s, partial_pos)))
+          if ((tmp= s->joinReadConstTable(partial_pos)))
           {
             if (tmp > 0)
               return 1;			// Fatal error
@@ -5794,7 +5793,7 @@
                 if (create_ref_for_key(join, s, start_keyuse, found_const_table_map))
                   return 1;
                 partial_pos= join->getSpecificPosInPartialPlan(const_count - 1);
-                if ((tmp=join_read_const_table(s, partial_pos)))
+                if ((tmp=s->joinReadConstTable(partial_pos)))
                 {
                   if (tmp > 0)
                     return 1;			// Fatal error
@@ -5959,7 +5958,7 @@
   TableList *table;
   while ((table= li++))
   {
-    nested_join_st *nested_join;
+    NestedJoin *nested_join;
     if ((nested_join= table->getNestedJoin()))
     {
       /*
@@ -6016,9 +6015,9 @@
 }
 
 /**
-  Set nested_join_st::counter=0 in all nested joins in passed list.
+  Set NestedJoin::counter=0 in all nested joins in passed list.
 
-    Recursively set nested_join_st::counter=0 for all nested joins contained in
+    Recursively set NestedJoin::counter=0 for all nested joins contained in
     the passed join_list.
 
   @param join_list  List of nested joins to process. It may also contain base
@@ -6030,7 +6029,7 @@
   TableList *table;
   while ((table= li++))
   {
-    nested_join_st *nested_join;
+    NestedJoin *nested_join;
     if ((nested_join= table->getNestedJoin()))
     {
       nested_join->counter_= 0;
@@ -6116,7 +6115,7 @@
   Join *join= last->join;
   for (;last_emb != NULL; last_emb= last_emb->getEmbedding())
   {
-    nested_join_st *nest= last_emb->getNestedJoin();
+    NestedJoin *nest= last_emb->getNestedJoin();
     
     bool was_fully_covered= nest->is_fully_covered();
     

=== modified file 'drizzled/join_table.cc'
--- drizzled/join_table.cc	2010-12-18 04:43:40 +0000
+++ drizzled/join_table.cc	2011-02-04 19:50:47 +0000
@@ -21,10 +21,89 @@
 #include "config.h"
 #include <drizzled/join_table.h>
 #include <drizzled/field/blob.h>
+#include <drizzled/sql_select.h>
 
 namespace drizzled
 {
 
+int JoinTable::joinReadConstTable(optimizer::Position *pos)
+{
+  int error;
+  Table *Table= this->table;
+  Table->const_table=1;
+  Table->null_row=0;
+  Table->status=STATUS_NO_RECORD;
+
+  if (this->type == AM_SYSTEM)
+  {
+    if ((error=join_read_system(this)))
+    {						// Info for DESCRIBE
+      this->info="const row not found";
+      /* Mark for EXPLAIN that the row was not found */
+      pos->setFanout(0.0);
+      pos->clearRefDependMap();
+      if (! Table->maybe_null || error > 0)
+        return(error);
+    }
+  }
+  else
+  {
+    if (! Table->key_read && 
+        Table->covering_keys.test(this->ref.key) && 
+        ! Table->no_keyread &&
+        (int) Table->reginfo.lock_type <= (int) TL_READ_WITH_SHARED_LOCKS)
+    {
+      Table->key_read=1;
+      Table->cursor->extra(HA_EXTRA_KEYREAD);
+      this->index= this->ref.key;
+    }
+    error=join_read_const(this);
+    if (Table->key_read)
+    {
+      Table->key_read=0;
+      Table->cursor->extra(HA_EXTRA_NO_KEYREAD);
+    }
+    if (error)
+    {
+      this->info="unique row not found";
+      /* Mark for EXPLAIN that the row was not found */
+      pos->setFanout(0.0);
+      pos->clearRefDependMap();
+      if (!Table->maybe_null || error > 0)
+        return(error);
+    }
+  }
+  if (*this->on_expr_ref && !Table->null_row)
+  {
+    if ((Table->null_row= test((*this->on_expr_ref)->val_int() == 0)))
+      Table->mark_as_null_row();
+  }
+  if (!Table->null_row)
+    Table->maybe_null=0;
+
+  /* Check appearance of new constant items in Item_equal objects */
+  Join *Join= this->join;
+  if (Join->conds)
+    update_const_equal_items(Join->conds, this);
+  TableList *tbl;
+  for (tbl= Join->select_lex->leaf_tables; tbl; tbl= tbl->next_leaf)
+  {
+    TableList *embedded;
+    TableList *embedding= tbl;
+    do
+    {
+      embedded= embedding;
+      if (embedded->on_expr)
+         update_const_equal_items(embedded->on_expr, this);
+      embedding= embedded->getEmbedding();
+    }
+    while (embedding &&
+           embedding->getNestedJoin()->join_list.head() == embedded);
+  }
+
+  return(0);
+}
+
 void JoinTable::readCachedRecord()
 {
   unsigned char *pos;

=== modified file 'drizzled/join_table.h'
--- drizzled/join_table.h	2010-12-18 04:43:40 +0000
+++ drizzled/join_table.h	2011-02-04 19:50:47 +0000
@@ -41,15 +41,18 @@
 namespace drizzled
 {
 
+class Table;
+
+namespace optimizer
+{
+  class Position;
+}
 /* Values for JoinTable::packed_info */
 #define TAB_INFO_HAVE_VALUE 1
 #define TAB_INFO_USING_INDEX 2
 #define TAB_INFO_USING_WHERE 4
 #define TAB_INFO_FULL_SCAN_ON_NULL 8
 
-class Table;
-
-
 /** Description of an access method */
 enum access_method
 { 
@@ -243,6 +246,7 @@
   }
 
   void readCachedRecord();
+  int joinReadConstTable(optimizer::Position *pos);
 };
 
 } /* namespace drizzled */

=== modified file 'drizzled/nested_join.h'
--- drizzled/nested_join.h	2010-12-18 04:43:40 +0000
+++ drizzled/nested_join.h	2011-02-04 19:50:47 +0000
@@ -22,15 +22,16 @@
 
 #include <drizzled/sql_list.h>
 #include <drizzled/item.h>
-#include <drizzled/table_list.h>
 
 #include <bitset>
 
 namespace drizzled
 {
+class TableList;
 
-struct nested_join_st
+class NestedJoin
 {
+public:
   /* list of elements in the nested join */
   List<TableList> join_list;
 

=== modified file 'drizzled/optimizer/position.h'
--- drizzled/optimizer/position.h	2010-12-18 04:43:40 +0000
+++ drizzled/optimizer/position.h	2011-02-04 18:26:39 +0000
@@ -20,7 +20,7 @@
 #ifndef DRIZZLED_OPTIMIZER_POSITION_H
 #define DRIZZLED_OPTIMIZER_POSITION_H
 
-#include <drizzled/join_table.h>
+#include "drizzled/join_table.h"
 
 namespace drizzled
 {

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2011-01-26 19:15:55 +0000
+++ drizzled/sql_parse.cc	2011-02-04 19:50:47 +0000
@@ -1058,12 +1058,12 @@
 bool Select_Lex::init_nested_join(Session *session)
 {
   TableList *ptr;
-  nested_join_st *nested_join;
+  NestedJoin *nested_join;
 
   if (!(ptr= (TableList*) session->calloc(ALIGN_SIZE(sizeof(TableList))+
-                                       sizeof(nested_join_st))))
+                                       sizeof(NestedJoin))))
     return true;
-  ptr->setNestedJoin(((nested_join_st*) ((unsigned char*) ptr + ALIGN_SIZE(sizeof(TableList)))));
+  ptr->setNestedJoin(((NestedJoin*) ((unsigned char*) ptr + ALIGN_SIZE(sizeof(TableList)))));
   nested_join= ptr->getNestedJoin();
   join_list->push_front(ptr);
   ptr->setEmbedding(embedding);
@@ -1093,7 +1093,7 @@
 TableList *Select_Lex::end_nested_join(Session *)
 {
   TableList *ptr;
-  nested_join_st *nested_join;
+  NestedJoin *nested_join;
 
   assert(embedding);
   ptr= embedding;
@@ -1134,13 +1134,13 @@
 TableList *Select_Lex::nest_last_join(Session *session)
 {
   TableList *ptr;
-  nested_join_st *nested_join;
+  NestedJoin *nested_join;
   List<TableList> *embedded_list;
 
   if (!(ptr= (TableList*) session->calloc(ALIGN_SIZE(sizeof(TableList))+
-                                          sizeof(nested_join_st))))
+                                          sizeof(NestedJoin))))
     return NULL;
-  ptr->setNestedJoin(((nested_join_st*) ((unsigned char*) ptr + ALIGN_SIZE(sizeof(TableList)))));
+  ptr->setNestedJoin(((NestedJoin*) ((unsigned char*) ptr + ALIGN_SIZE(sizeof(TableList)))));
   nested_join= ptr->getNestedJoin();
   ptr->setEmbedding(embedding);
   ptr->setJoinList(join_list);

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2011-01-26 23:20:53 +0000
+++ drizzled/sql_select.cc	2011-02-04 19:50:47 +0000
@@ -2307,7 +2307,7 @@
   @param cond       condition whose multiple equalities are to be checked
   @param table      constant table that has been read
 */
-static void update_const_equal_items(COND *cond, JoinTable *tab)
+void update_const_equal_items(COND *cond, JoinTable *tab)
 {
   if (!(cond->used_tables() & tab->table->map))
     return;
@@ -2606,7 +2606,7 @@
          position:
           1. join->cur_embedding_map - bitmap of pairs of brackets (aka nested
              joins) we've opened but didn't close.
-          2. {each nested_join_st structure not simplified away}->counter - number
+          2. {each NestedJoin class not simplified away}->counter - number
              of this nested join's children that have already been added to to
              the partial join order.
   @endverbatim
@@ -3367,83 +3367,6 @@
   return 0;
 }
 
-int join_read_const_table(JoinTable *tab, optimizer::Position *pos)
-{
-  int error;
-  Table *table=tab->table;
-  table->const_table=1;
-  table->null_row=0;
-  table->status=STATUS_NO_RECORD;
-
-  if (tab->type == AM_SYSTEM)
-  {
-    if ((error=join_read_system(tab)))
-    {						// Info for DESCRIBE
-      tab->info="const row not found";
-      /* Mark for EXPLAIN that the row was not found */
-      pos->setFanout(0.0);
-      pos->clearRefDependMap();
-      if (! table->maybe_null || error > 0)
-        return(error);
-    }
-  }
-  else
-  {
-    if (! table->key_read && 
-        table->covering_keys.test(tab->ref.key) && 
-        ! table->no_keyread &&
-        (int) table->reginfo.lock_type <= (int) TL_READ_WITH_SHARED_LOCKS)
-    {
-      table->key_read=1;
-      table->cursor->extra(HA_EXTRA_KEYREAD);
-      tab->index= tab->ref.key;
-    }
-    error=join_read_const(tab);
-    if (table->key_read)
-    {
-      table->key_read=0;
-      table->cursor->extra(HA_EXTRA_NO_KEYREAD);
-    }
-    if (error)
-    {
-      tab->info="unique row not found";
-      /* Mark for EXPLAIN that the row was not found */
-      pos->setFanout(0.0);
-      pos->clearRefDependMap();
-      if (!table->maybe_null || error > 0)
-        return(error);
-    }
-  }
-  if (*tab->on_expr_ref && !table->null_row)
-  {
-    if ((table->null_row= test((*tab->on_expr_ref)->val_int() == 0)))
-      table->mark_as_null_row();
-  }
-  if (!table->null_row)
-    table->maybe_null=0;
-
-  /* Check appearance of new constant items in Item_equal objects */
-  Join *join= tab->join;
-  if (join->conds)
-    update_const_equal_items(join->conds, tab);
-  TableList *tbl;
-  for (tbl= join->select_lex->leaf_tables; tbl; tbl= tbl->next_leaf)
-  {
-    TableList *embedded;
-    TableList *embedding= tbl;
-    do
-    {
-      embedded= embedding;
-      if (embedded->on_expr)
-         update_const_equal_items(embedded->on_expr, tab);
-      embedding= embedded->getEmbedding();
-    }
-    while (embedding &&
-           embedding->getNestedJoin()->join_list.head() == embedded);
-  }
-
-  return(0);
-}
 
 int join_read_system(JoinTable *tab)
 {

=== modified file 'drizzled/sql_select.h'
--- drizzled/sql_select.h	2011-01-17 07:58:22 +0000
+++ drizzled/sql_select.h	2011-02-04 18:26:39 +0000
@@ -30,6 +30,7 @@
 #include "drizzled/optimizer/key_use.h"
 #include "drizzled/join_cache.h"
 #include "drizzled/join_table.h"
+#include "drizzled/records.h"
 
 #include <vector>
 
@@ -203,8 +204,7 @@
 			                         List<Item> &all_fields);
 bool change_group_ref(Session *session, Item_func *expr, Order *group_list, bool *changed);
 bool check_interleaving_with_nj(JoinTable *next);
-
-int join_read_const_table(JoinTable *tab, optimizer::Position *pos);
+void update_const_equal_items(COND *cond, JoinTable *tab);
 int join_read_system(JoinTable *tab);
 int join_read_const(JoinTable *tab);
 int join_read_key(JoinTable *tab);

=== modified file 'drizzled/table_list.cc'
--- drizzled/table_list.cc	2010-12-18 04:43:40 +0000
+++ drizzled/table_list.cc	2011-02-04 19:50:47 +0000
@@ -76,7 +76,7 @@
 TableList *TableList::last_leaf_for_name_resolution()
 {
   TableList *cur_table_ref= this;
-  nested_join_st *cur_nested_join;
+  NestedJoin *cur_nested_join;
 
   if (is_leaf_for_name_resolution())
     return this;
@@ -114,7 +114,7 @@
 TableList *TableList::first_leaf_for_name_resolution()
 {
   TableList *cur_table_ref= NULL;
-  nested_join_st *cur_nested_join;
+  NestedJoin *cur_nested_join;
 
   if (is_leaf_for_name_resolution())
     return this;

=== modified file 'drizzled/table_list.h'
--- drizzled/table_list.h	2011-02-01 23:30:35 +0000
+++ drizzled/table_list.h	2011-02-04 19:50:47 +0000
@@ -21,6 +21,7 @@
 #ifndef DRIZZLED_TABLE_LIST_H
 #define DRIZZLED_TABLE_LIST_H
 
+#include <drizzled/nested_join.h>
 #include <drizzled/table.h>
 
 namespace drizzled
@@ -41,8 +42,6 @@
   class StorageEngine;
 }
 
-struct nested_join_st;
-
 /**
  * A Table referenced in the FROM clause.
  *
@@ -462,7 +461,7 @@
     embedding= in_embedding;
   }
 
-  void setNestedJoin(nested_join_st *in_nested_join)
+  void setNestedJoin(NestedJoin *in_nested_join)
   {
     nested_join= in_nested_join;
   }
@@ -512,7 +511,7 @@
     return join_list;
   }
 
-  nested_join_st *getNestedJoin() const
+  NestedJoin *getNestedJoin() const
   {
     return nested_join;
   }
@@ -533,7 +532,7 @@
 private:
   table_map dep_tables; ///< tables the table depends on
   table_map on_expr_dep_tables; ///< tables on expression depends on
-  nested_join_st *nested_join; ///< if the element is a nested join
+  NestedJoin *nested_join; ///< if the element is a nested join
   TableList *embedding; ///< nested join containing the table
   List<TableList> *join_list; ///< join list the table belongs to
   plugin::StorageEngine *db_type; ///< table_type for handler

